"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = loader;
var _frontMatter = _interopRequireDefault(require("front-matter"));
var _options = _interopRequireDefault(require("./options.json"));
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
async function loader(content) {
  const options = this.getOptions(_options.default);
  const remarkOptions = typeof options.remarkOptions !== "undefined" ? options.remarkOptions : {};
  const callback = this.async();
  let remark;
  try {
    ({
      remark
    } = await import("remark"));
  } catch (error) {
    callback(error);
    return;
  }
  const processor = remark();
  if (typeof remarkOptions.plugins !== "undefined") {
    for (const item of remarkOptions.plugins) {
      if (Array.isArray(item)) {
        const [plugin, pluginOptions] = item;
        processor.use(plugin, pluginOptions);
      } else {
        processor.use(item);
      }
    }
  }
  if (typeof remarkOptions.settings !== "undefined") {
    processor.use({
      settings: remarkOptions.settings
    });
  }
  if (typeof remarkOptions.data !== "undefined") {
    processor.data(remarkOptions.data);
  }
  const removeFrontMatter = typeof options.removeFrontMatter !== "undefined" ? options.removeFrontMatter : true;
  let file;
  try {
    file = await processor.process(removeFrontMatter ? (0, _frontMatter.default)(content).body : content);
  } catch (error) {
    const Report = (await import("vfile-reporter")).default;
    callback(Report(error));
    return;
  }
  let valueToEmit;
  try {
    valueToEmit = JSON.stringify(file);
  } catch (error) {
    callback(error);
    return;
  }
  callback(null, valueToEmit);
}